HzyNormalHttpConfig class

dio 配置项

Constructors

HzyNormalHttpConfig({String? baseUrl, String? proxy, String contentType = "application/json", Map<String, dynamic>? headers, String? cookiesPath, List<Interceptor>? interceptors, bool isNeedLog = true, int caCheStatusCode = 304, int connectTimeout = 30, int sendTimeout = 30, int receiveTimeout = 30})

Properties

baseUrl String?
final
caCheStatusCode int
网络缓存 状态值
final
connectTimeout int
final
contentType String
final
cookiesPath String?
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, dynamic>?
final
interceptors List<Interceptor>?
final
isNeedLog bool
final
proxy String?
final
receiveTimeout int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendTimeout int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited