HzyNormalResponse class
Constructors
-
HzyNormalResponse.fail({required dynamic data, String? errorMsg = '网络请求失败', int? errorCode = 404, Map<
String, dynamic> ? response}) - HzyNormalResponse.failureFormResponse({dynamic data})
- HzyNormalResponse.failureFromError([HzyNormalExceeption? requesError])
-
HzyNormalResponse.success({required dynamic netData, Map<
String, dynamic> ? response, String reqMsg = "请求成功"})
Properties
- data ↔ dynamic
-
getter/setter pair
- error ↔ HzyNormalExceeption?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- msg ↔ String
-
getter/setter pair
- ok ↔ bool
-
getter/setter pair
-
response
↔ Map<
String, dynamic> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited